@@ -1,6 +1,6 @@
 from scripts.bigdirs import bigdirs, process_bigdirs
-from scripts.dedupe import deduplicate_db
-from scripts.invalid_paths import rename_invalid_paths
+from scripts.christen import christen
+from scripts.dedupe import dedupe
 from scripts.merge_dbs import merge_dbs
 from scripts.merge_online_local import merge_online_local
 from scripts.mining.nfb_ca import nfb_films
@@ -10,5 +10,6 @@ from scripts.mining.reddit_self import parse_reddit_selftext
 from scripts.move_list import move_list
 from scripts.optimize_db import optimize_db
 from scripts.redownload import redownload
+from scripts.relmv import relmv
 from scripts.scatter import scatter, scatter_usage
 from scripts.streaming_tab_loader import streaming_tab_loader
