@@ -71,11 +71,18 @@ def usage(action) -> str:
         library {action} -p  # this will print _all_ the media. be cautious about `-p` on an unfiltered set
 
         Printing modes
-        library {action} -p    # print in a table
-        library {action} -p p  # equivalent
+        library {action} -p    # print as a table
         library {action} -p a  # print an aggregate report
         library {action} -p b  # print a bigdirs report (see lb bigdirs -h for more info)
-        library {action} -p f  # print fields -- useful for piping paths to utilities like xargs or GNU Parallel
+        library {action} -p f  # print fields (defaults to path; use --cols to change)
+                               # -- useful for piping paths to utilities like xargs or GNU Parallel
+
+        library {action} -p d  # mark deleted
+        library {action} -p w  # mark watched
+
+        Some printing modes can be combined
+        library {action} -p df  # print files for piping into another program and mark them as deleted within the db
+        library {action} -p bf  # print fields from bigdirs report
 
         Check if you have downloaded something before
         library {action} -u duration -p -s 'title'
@@ -91,14 +98,17 @@ def usage(action) -> str:
         ╘═══════════╧══════════════╧═════════╧═════════╛
         Total duration: 14 days, 23 hours and 42 minutes
 
-        Print an aggregate report of media that has no duration information (likely corrupt or online media)
+        Print an aggregate report of media that has no duration information (ie. online or corrupt local media)
         library {action} -w 'duration is null' -p=a
 
         Print a list of filenames which have below 1280px resolution
         library {action} -w 'width<1280' -p=f
 
         Print media you have partially viewed with mpv
-        library {action} -p=v
+        library {action} --partial -p
+        library {action} -P -p  # equivalent
+        library {action} -P -p f --cols path,progress,duration  # print CSV of partially watched files
+        library {action} --partial -pa  # print an aggregate report of partially watched files
 
         View how much time you have {action}ed
         library {action} -w play_count'>'0 -p=a
@@ -465,34 +475,34 @@ def parse_args(action, default_chromecast=None) -> argparse.Namespace:
     return args
 
 
-def construct_search_bindings(args, cf, bindings, columns) -> None:
+def construct_search_bindings(args, columns) -> None:
     includes, excludes = db.gen_include_excludes(columns)
 
     for idx, inc in enumerate(args.include):
-        cf.append(includes.format(idx))
-        bindings[f"include{idx}"] = "%" + inc.replace(" ", "%").replace("%%", " ") + "%"
+        args.filter_sql.append(includes.format(idx))
+        args.filter_bindings[f"include{idx}"] = "%" + inc.replace(" ", "%").replace("%%", " ") + "%"
     for idx, exc in enumerate(args.exclude):
-        cf.append(excludes.format(idx))
-        bindings[f"exclude{idx}"] = "%" + exc.replace(" ", "%").replace("%%", " ") + "%"
+        args.filter_sql.append(excludes.format(idx))
+        args.filter_bindings[f"exclude{idx}"] = "%" + exc.replace(" ", "%").replace("%%", " ") + "%"
 
 
 def construct_query(args) -> Tuple[str, dict]:
     m_columns = args.db["media"].columns_dict
-    cf = []
-    bindings = {}
+    args.filter_sql = []
+    args.filter_bindings = {}
 
     if args.duration:
-        cf.append(" and duration IS NOT NULL " + args.duration)
+        args.filter_sql.append(" and duration IS NOT NULL " + args.duration)
     if args.size:
-        cf.append(" and size IS NOT NULL " + args.size)
+        args.filter_sql.append(" and size IS NOT NULL " + args.size)
     if args.duration_from_size:
-        cf.append(
+        args.filter_sql.append(
             " and size IS NOT NULL and duration in (select distinct duration from m where 1=1 "
             + args.duration_from_size
             + ")"
         )
 
-    cf.extend([" and " + w for w in args.where])
+    args.filter_sql.extend([" and " + w for w in args.where])
 
     def ii(string):
         if string.isdigit():
@@ -500,35 +510,51 @@ def construct_query(args) -> Tuple[str, dict]:
         return string.replace("mins", "minutes").replace("secs", "seconds")
 
     if args.created_within:
-        cf.append(f"and time_created > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.created_within)}')) as int)")
+        args.filter_sql.append(
+            f"and time_created > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.created_within)}')) as int)"
+        )
     if args.created_before:
-        cf.append(f"and time_created < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.created_before)}')) as int)")
+        args.filter_sql.append(
+            f"and time_created < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.created_before)}')) as int)"
+        )
     if args.changed_within:
-        cf.append(f"and time_modified > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.changed_within)}')) as int)")
+        args.filter_sql.append(
+            f"and time_modified > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.changed_within)}')) as int)"
+        )
     if args.changed_before:
-        cf.append(f"and time_modified < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.changed_before)}')) as int)")
+        args.filter_sql.append(
+            f"and time_modified < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.changed_before)}')) as int)"
+        )
     if args.played_within:
-        cf.append(f"and time_played > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.played_within)}')) as int)")
+        args.filter_sql.append(
+            f"and time_played > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.played_within)}')) as int)"
+        )
     if args.played_before:
-        cf.append(f"and time_played < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.played_before)}')) as int)")
+        args.filter_sql.append(
+            f"and time_played < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.played_before)}')) as int)"
+        )
     if args.deleted_within:
-        cf.append(f"and time_deleted > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.deleted_within)}')) as int)")
+        args.filter_sql.append(
+            f"and time_deleted > cast(STRFTIME('%s', datetime( 'now', '-{ii(args.deleted_within)}')) as int)"
+        )
     if args.deleted_before:
-        cf.append(f"and time_deleted < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.deleted_before)}')) as int)")
+        args.filter_sql.append(
+            f"and time_deleted < cast(STRFTIME('%s', datetime( 'now', '-{ii(args.deleted_before)}')) as int)"
+        )
 
     args.table = "media"
     if args.db["media"].detect_fts():
         if args.include:
-            args.table = db.fts_search(args, bindings)
+            args.table = db.fts_search(args)
             m_columns = {**m_columns, "rank": int}
         elif args.exclude:
-            construct_search_bindings(args, cf, bindings, m_columns)
+            construct_search_bindings(args, m_columns)
     else:
-        construct_search_bindings(args, cf, bindings, m_columns)
+        construct_search_bindings(args, m_columns)
 
     if args.table == "media" and not any(
         [
-            cf,
+            args.filter_sql,
             args.where,
             args.print,
             args.partial,
@@ -548,10 +574,9 @@ def construct_query(args) -> Tuple[str, dict]:
                 if "time_deleted" in m_columns and "time_deleted" not in " ".join(sys.argv)
                 else ""
             )
-            cf.append(f"and m.rowid in (select rowid from media {where_not_deleted} order by random() limit {limit})")
-
-    args.sql_filter = " ".join(cf)
-    args.sql_filter_bindings = bindings
+            args.filter_sql.append(
+                f"and m.rowid in (select rowid from media {where_not_deleted} order by random() limit {limit})"
+            )
 
     duration = "duration"
     if args.action == SC.read:
@@ -565,7 +590,7 @@ def construct_query(args) -> Tuple[str, dict]:
     SELECT rowid, * FROM {args.table}
     WHERE 1=1
         {f'and path like "http%"' if args.safe else ''}
-        {f'and path not like "{Path(args.keep_dir).resolve()}%"' if args.post_action == 'askkeep' else ''}
+        {f'and path not like "{args.keep_dir}%"' if Path(args.keep_dir).exists() else ''}
         {'and COALESCE(time_deleted,0) = 0' if 'time_deleted' in m_columns and 'time_deleted' not in ' '.join(sys.argv) else ''}
         {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
         {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
@@ -576,13 +601,17 @@ def construct_query(args) -> Tuple[str, dict]:
         {SELECT}
     FROM m
     WHERE 1=1
-        {args.sql_filter}
+        {" ".join(args.filter_sql)}
     ORDER BY 1=1
         , {args.sort}
     {LIMIT} {OFFSET}
     """
 
-    return query, bindings
+    args.filter_sql = [
+        s for s in args.filter_sql if "rowid" not in s
+    ]  # only use random rowid constraint in first query
+
+    return query, args.filter_bindings
 
 
 def chromecast_play(args, m) -> None:
