@@ -1,4 +1,4 @@
-import csv, operator, os, platform, re, shutil, socket, subprocess
+import csv, operator, os, platform, re, shutil, socket, subprocess, sys
 from copy import deepcopy
 from io import StringIO
 from numbers import Number
@@ -358,16 +358,16 @@ def get_ordinal_media(args, path: str) -> str:
             WHERE 1=1
                 and path like :candidate
                 {'and COALESCE(time_deleted,0) = 0' if 'time_deleted' in columns else ''}
-                {'' if args.play_in_order >= 2 else (args.sql_filter or '')}
+                {'' if args.play_in_order >= 2 else (" ".join(args.filter_sql) or '')}
             ORDER BY play_count, path
             LIMIT 1000
             """
         bindings = {"candidate": candidate + "%"}
         if args.play_in_order == 1:
             if args.include or args.exclude:
-                bindings = {**bindings, "query": args.sql_filter_bindings["query"]}
+                bindings = {**bindings, "query": args.filter_bindings["query"]}
         else:
-            bindings = {**bindings, **args.sql_filter_bindings}
+            bindings = {**bindings, **args.filter_bindings}
 
         similar_videos = [d["path"] for d in args.db.query(query, bindings)]
         log.debug(similar_videos)
@@ -579,7 +579,7 @@ def gui_post_act(args, media, m, geom_data=None):
         elif r == "KEEP" and args.post_action == "askkeep":
             mv_to_keep_folder(args, m["path"])
         else:
-            raise Exception("I did not quite catch that... what did you say?")
+            raise NotImplementedError
     else:
         post_act(args, m["path"])
 
@@ -690,22 +690,21 @@ def printer(args, query, bindings) -> None:
                     D[f"avg_{c}"] = sum((d[c] or 0) for d in media) / len(media)
         media = [D]
 
-    elif "d" in args.print:
-        mark_media_deleted(args, list(map(operator.itemgetter("path"), media)))
-        if not "f" in args.print:
-            return print(f"Removed {len(media)} metadata records")
-    elif "w" in args.print:
-        marked = mark_media_watched(args, list(map(operator.itemgetter("path"), media)))
-        if not "f" in args.print:
-            return print(f"Marked {marked} metadata records as watched")
+    else:
+        if "d" in args.print:
+            marked = mark_media_deleted(args, list(map(operator.itemgetter("path"), media)))
+            print(f"Marked {marked} metadata records as deleted", file=sys.stderr)
+        if "w" in args.print:
+            marked = mark_media_watched(args, list(map(operator.itemgetter("path"), media)))
+            print(f"Marked {marked} metadata records as watched", file=sys.stderr)
 
     if "f" in args.print:
         if args.limit == 1:
             f = media[0]["path"]
             if not Path(f).exists():
                 mark_media_deleted(args, f)
-                return printer(args, query, bindings)
-            print(quote(f))
+                return printer(args, query, bindings)  # try again to find a valid file
+            utils.pipe_print(quote(f))
         else:
             if not args.cols:
                 args.cols = ["path"]
